package com.meas.system.service.impl;

import com.meas.common.utils.DateUtils;
import com.meas.system.domain.MeasDataResults;
import com.meas.system.mapper.MeasDataResultsMapper;
import com.meas.system.service.IMeasDataResultsService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 数据结果Service业务层处理
 *
 * @author wgk
 * @date 2024-06-13
 */
@Service
public class MeasDataResultsServiceImpl implements IMeasDataResultsService {
    @Autowired
    private MeasDataResultsMapper measDataResultsMapper;

    /**
     * 查询数据结果
     *
     * @param id 数据结果主键
     * @return 数据结果
     */
    @Override
    public MeasDataResults selectMeasDataResultsById(Long id) {
        return measDataResultsMapper.selectMeasDataResultsById(id);
    }

    /**
     * 查询数据结果列表
     *
     * @param measDataResults 数据结果
     * @return 数据结果
     */
    @Override
    public List<MeasDataResults> selectMeasDataResultsList(MeasDataResults measDataResults) {
        return measDataResultsMapper.selectMeasDataResultsList(measDataResults);
    }

    /**
     * 新增数据结果
     *
     * @param measDataResults 数据结果
     * @return 结果
     */
    @Override
    public MeasDataResults insertMeasDataResults(MeasDataResults measDataResults) {
        measDataResults.setCreateTime(DateUtils.getNowDate());
        int i = measDataResultsMapper.insertMeasDataResults(measDataResults);
        if (i > 0) {
            return measDataResults;
        } else {
            return null;
        }
    }

    /**
     * 修改数据结果
     *
     * @param measDataResults 数据结果
     * @return 结果
     */
    @Override
    public int updateMeasDataResults(MeasDataResults measDataResults) {
        measDataResults.setUpdateTime(DateUtils.getNowDate());
        return measDataResultsMapper.updateMeasDataResults(measDataResults);
    }

    /**
     * 批量删除数据结果
     *
     * @param ids 需要删除的数据结果主键
     * @return 结果
     */
    @Override
    public int deleteMeasDataResultsByIds(Long[] ids) {
        return measDataResultsMapper.deleteMeasDataResultsByIds(ids);
    }

    /**
     * 删除数据结果信息
     *
     * @param id 数据结果主键
     * @return 结果
     */
    @Override
    public int deleteMeasDataResultsById(Long id) {
        return measDataResultsMapper.deleteMeasDataResultsById(id);
    }

    @Override
    public MeasDataResults selectMeasDataResultsByEnvDataId(Long envDataId) {
        return measDataResultsMapper.selectMeasDataResultsByEnvDataId(envDataId);
    }
}
